import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import cx from 'classnames';
import AtomImage from '@s-ui/react-atom-image';
import AtomSkeleton from '@s-ui/react-atom-skeleton';
import useConvertStringToHex from './useConvertStringToHex';
import AvatarFallback from './AvatarFallback';
import AvatarBadge from './AvatarBadge';
export var AVATAR_SIZES = {
  XLARGE: 'xlarge',
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small'
};

var MoleculeAvatar = function MoleculeAvatar(_ref) {
  var classNameProp = _ref.className,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? AVATAR_SIZES.MEDIUM : _ref$size,
      _ref$skeleton = _ref.skeleton,
      skeleton = _ref$skeleton === void 0 ? /*#__PURE__*/React.createElement(AtomSkeleton, {
    width: "100%",
    height: "100%",
    animation: "wave"
  }) : _ref$skeleton,
      name = _ref.name,
      src = _ref.src,
      fallbackIcon = _ref.fallbackIcon,
      style = _ref.style,
      isLoading = _ref.isLoading,
      childrenProp = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, ["className", "size", "skeleton", "name", "src", "fallbackIcon", "style", "isLoading", "children"]);

  var baseClassName = 'sui-MoleculeAvatar';
  var className = cx(baseClassName, baseClassName + "--" + size);
  var backgroundColor = useConvertStringToHex(name);
  var children = React.Children.toArray(childrenProp).filter(function (child) {
    return /*#__PURE__*/React.isValidElement(child);
  }).map(function (child) {
    return /*#__PURE__*/React.cloneElement(child, {
      size: size
    });
  });

  var renderFallback = function renderFallback() {
    return /*#__PURE__*/React.createElement(AvatarFallback, {
      name: name,
      size: size,
      icon: fallbackIcon
    });
  };

  var renderContent = function renderContent() {
    if (isLoading) {
      return skeleton;
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, src ? /*#__PURE__*/React.createElement(AtomImage, {
      src: src,
      alt: name,
      errorIcon: renderFallback()
    }) : renderFallback(), !isLoading && children);
  };

  return /*#__PURE__*/React.createElement("span", Object.assign({
    style: _extends({}, style, {
      backgroundColor: backgroundColor
    }),
    className: className
  }, others), renderContent());
};

MoleculeAvatar.displayName = 'MoleculeAvatar';
MoleculeAvatar.Badge = AvatarBadge;
export default MoleculeAvatar;